@@ -30,7 +30,7 @@ class server:
         code = client.recv(4096)
         return code
     def regions():
-        return "SMTP regions: de, uk, au"
+        return "SMTP regions: de, uk, us, it, es, tw, cn, ar, au"
     def debug(type:str):
         global debug
         if type == "on":
